local E, L, V, P, G = unpack(ElvUI) -- import: Engine, Locales, PrivateDB, ProfileDB, GlobalDB
local EDB = E:GetModule("DataBars") -- ElvUI's DataBars
local EPDBC = E:GetModule("EPDBC") -- this AddOn

-- local variables ------------------------------------------------------------
local EPDBC_ASCII_REP_BAR_COLORS = {
    [1] = {r = 1, g = 0, b = 0, a = 1},             -- hated
    [2] = {r = 1, g = 0.55, b = 0, a = 1},          -- hostile
    [3] = {r = 1, g = 1, b = 0, a = 1},             -- unfriendly
    [4] = {r = 1, g = 1, b = 1, a = 1},             -- neutral
    [5] = {r = 0, g = 1, b = 0, a = 1},             -- friendly
    [6] = {r = 0.25,  g = 0.4,  b = 0.9, a = 1},    -- honored
    [7] = {r = 0.6, g = 0.2, b = 0.8, a = 1},       -- revered
    [8] = {r = 0.9, g = 0.8,  b = 0.5, a = 1},      -- exalted
}
local BACKUP = FACTION_BAR_COLORS[1]

-- local functions called via hooking -----------------------------------------
local function ReputationBar_OnEnter()
    local name, reaction, minimum, maximum, value = GetWatchedFactionInfo()
    local isCapped

    if reaction == MAX_REPUTATION_REACTION then
		-- max rank, make it look like a full bar
		minimum, maximum, value = 0, 1, 1
		isCapped = true
	end

    if name and E.db.EPDBC.reputationBar.capped then
        if isCapped then
            GameTooltip:ClearLines()

            GameTooltip:AddLine(" ")
            GameTooltip:AddDoubleLine(name .. ":", L["Capped"])
            GameTooltip:Show()
        end
    end
end

local function UpdateReputation(self)
    local name, reaction, minimum, maximum, value = GetWatchedFactionInfo()
    local isCapped
    local bar = self.repBar

    if reaction == MAX_REPUTATION_REACTION then
		-- max rank, make it look like a full bar
		minimum, maximum, value = 0, 1, 1
		isCapped = true
	end

    if name then -- only do stuff if name has value
        if E.db.EPDBC.reputationBar.capped then
            if isCapped then
                bar.text:SetText(name .. ": " .. L["Capped"])
            end
        end

        -- color the rep bar
        local choice = E.db.EPDBC.reputationBar.color
        local color

        if choice == "ascii" then
            color = EPDBC_ASCII_REP_BAR_COLORS[reaction] or BACKUP
        elseif choice == "custom" then
            color = E.db.EPDBC.reputationBar.userColors[reaction] or BACKUP
        else
            color = FACTION_BAR_COLORS[reaction] or BACKUP
        end

        bar.statusBar:SetStatusBarColor(color.r, color.g, color.b)

        -- blend the bar
        local avg = minimum / maximum
        avg = EPDBC:Round(avg, 2)
        if E.db.EPDBC.reputationBar.progress then
            bar.statusBar:SetAlpha(avg)
        else
            bar.statusBar:SetAlpha(1)
        end
    end
end

-- hooking fuctions -----------------------------------------------------------
function EPDBC:HookRepTooltip()
    local bar = EDB.repBar
    if E.db.EPDBC.enabled and bar then
        if not EPDBC:IsHooked(ElvUI_ReputationBar, "OnEnter") then
            EPDBC:SecureHookScript(ElvUI_ReputationBar, "OnEnter", ReputationBar_OnEnter)
        end
    elseif not E.db.EPDBC.enabled or not bar then
        if EPDBC:IsHooked(ElvUI_ReputationBar, "OnEnter") then
            EPDBC:Unhook(ElvUI_ReputationBar, "OnEnter")
        end
    end
end

function EPDBC:HookRepText()
    local bar = EDB.repBar
    if E.db.EPDBC.enabled and bar then
        if not EPDBC:IsHooked(EDB, "UpdateReputation") then
            EPDBC:SecureHook(EDB, "UpdateReputation", UpdateReputation)
        end
    elseif not E.db.EPDBC.enabled or not bar then
        if EPDBC:IsHooked(EDB, "UpdateReputation") then
            EPDBC:Unhook(EDB, "UpdateReputation")
        end
        EPDBC:RestoreRepColors()
    end
    EDB:UpdateReputation()
end

function EPDBC:RestoreRepColors()
    local bar = EDB.repBar
    if bar then
        local _, reaction = GetWatchedFactionInfo()
        local color = FACTION_BAR_COLORS[reaction] or BACKUP

        bar.statusBar:SetStatusBarColor(color.r, color.g, color.b)
        bar.statusBar:SetAlpha(1)
    end
end
